﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Media;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            Loaded                           += Window_Loaded;
            this.redScrollBar.ValueChanged   += colorScrollBar_ValueChanged;
            this.greenScrollBar.ValueChanged += colorScrollBar_ValueChanged;
            this.blueScrollBar.ValueChanged  += colorScrollBar_ValueChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 윈도우 로드시 처리하기 - Window_Loaded(sender, e)

        /// <summary>
        /// 윈도우 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            Color color = (this.stackPanel.Background as SolidColorBrush).Color;

            this.redScrollBar.Value   = color.R;
            this.greenScrollBar.Value = color.G;
            this.blueScrollBar.Value  = color.B;

            this.redScrollBar.Focus();
        }

        #endregion
        #region 색상 스크롤바 값 변경시 처리하기 - colorScrollBar_ValueChanged(sender, e)

        /// <summary>
        /// 색상 스크롤바 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void colorScrollBar_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            ScrollBar scrollBar = sender as ScrollBar;

            Panel panel = scrollBar.Parent as Panel;

            TextBlock textBlock;
            
            if(scrollBar == this.redScrollBar)
            {
                textBlock = this.redTextBlock;
            }
            else if(scrollBar == this.greenScrollBar)
            {
                textBlock = this.greenTextBlock;
            }
            else
            {
                textBlock = this.blueTextBlock;
            }

            textBlock.Text = string.Format("{0}\n0x{0:X2}", (int)scrollBar.Value);

            this.stackPanel.Background = new SolidColorBrush
            (
                Color.FromRgb
                (
                    (byte)redScrollBar.Value,
                    (byte)greenScrollBar.Value,
                    (byte)blueScrollBar.Value
                )
            );
        }

        #endregion
    }
}